California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 010 - ALTERNATIVE FUEL VEHICLES AND RENEWABLE ENERGY. BONDS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1303380 | CALIFORNIANS FOR ENERGY INDEPENDENCE - YES ON PROP 10, A COALITION OF RENEWABLE ENERGY AND ALTERNATIVE FUEL COMPANIES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1311406 | NO ON PROPOSITION 10 CALIFORNIANS AGAINST THE $10 BILLION LEMON SPONSORED BY THE CONSUMER FEDERATION OF CALIFORNIA | OPPOSE